==> hubzero-cms-2.0.0_2.0.0.0.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.0/cms/core/components/com_wiki/helpers/utfnormalutil.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// No direct access.
defined('_HZEXEC_') or die();

/**
 * Based on code by Brion Vibber <brion@pobox.com>
 * Some of these functions are adapted from places in MediaWiki.
 * Should probably merge them for consistency.
 */

/**
 * Return UTF-8 sequence for a given Unicode code point.
 * May die if fed out of range data.
 *
 * @param  $codepoint Integer:
 * @return String
 * @public
 */
function codepointToUtf8($codepoint)
{
	if ($codepoint < 0x80)
	{
		return chr($codepoint);
	}
	if ($codepoint < 0x800)
	{
		return chr($codepoint >> 6 & 0x3f | 0xc0) . chr($codepoint & 0x3f | 0x80);
	}
	if ($codepoint < 0x10000)
	{
		return chr($codepoint >> 12 & 0x0f | 0xe0) . chr($codepoint >> 6 & 0x3f | 0x80) . chr($codepoint & 0x3f | 0x80);
	}
	if ($codepoint < 0x110000)
	{
		return chr($codepoint >> 18 & 0x07 | 0xf0) . chr($codepoint >> 12 & 0x3f | 0x80) . chr($codepoint >> 6 & 0x3f | 0x80) . chr($codepoint & 0x3f | 0x80);
	}

	echo "Asked for code outside of range ($codepoint)\n";
	die(-1);
}

/**
 * Take a series of space-separated hexadecimal numbers representing
 * Unicode code points and return a UTF-8 string composed of those
 * characters. Used by UTF-8 data generation and testing routines.
 *
 * @param   $sequence String
 * @return  String
 * @private
 */
function hexSequenceToUtf8($sequence)
{
	$utf = '';
	foreach (explode(' ', $sequence) as $hex)
	{
		$n = hexdec($hex);
		$utf .= codepointToUtf8($n);
	}
	return $utf;
}

/**
 * Take a UTF-8 string and return a space-separated series of hex
 * numbers representing Unicode code points. For debugging.
 *
 * @param   $str   String: UTF-8 string.
 * @return  string
 * @private
 */
function utf8ToHexSequence($str)
{
	return rtrim(preg_replace('/(.)/uSe', 'sprintf("%04x ", utf8ToCodepoint("$1"))', $str));
}

/**
 * Determine the Unicode codepoint of a single-character UTF-8 sequence.
 * Does not check for invalid input data.
 *
 * @param  $char   String
 * @return Integer
 * @public
 */
function utf8ToCodepoint($char)
{
	# Find the length
	$z = ord($char{0});
	if ($z & 0x80)
	{
		$length = 0;
		while ($z & 0x80)
		{
			$length++;
			$z <<= 1;
		}
	}
	else
	{
		$length = 1;
	}

	if ($length != strlen($char))
	{
		return false;
	}
	if ($length == 1)
	{
		return ord($char);
	}

	# Mask off the length-determining bits and shift back to the original location
	$z &= 0xff;
	$z >>= $length;

	# Add in the free bits from subsequent bytes
	for ($i=1; $i<$length; $i++)
	{
		$z <<= 6;
		$z |= ord($char{$i}) & 0x3f;
	}

	return $z;
}

/**
 * Escape a string for inclusion in a PHP single-quoted string literal.
 *
 * @param  $string String: string to be escaped.
 * @return String: escaped string.
 * @public
 */
function escapeSingleString($string)
{
	return strtr($string,
		array(
			'\\' => '\\\\',
			'\'' => '\\\''
		));
}

==> hubzero-cms-2.0.0_2.0.0.9.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.9/cms/core/components/com_wiki/helpers/utfnormalutil.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

// No direct access.
defined('_HZEXEC_') or die();

/**
 * Based on code by Brion Vibber <brion@pobox.com>
 * Some of these functions are adapted from places in MediaWiki.
 * Should probably merge them for consistency.
 */

/**
 * Return UTF-8 sequence for a given Unicode code point.
 * May die if fed out of range data.
 *
 * @param  $codepoint Integer:
 * @return String
 * @public
 */
function codepointToUtf8($codepoint)
{
	if ($codepoint < 0x80)
	{
		return chr($codepoint);
	}
	if ($codepoint < 0x800)
	{
		return chr($codepoint >> 6 & 0x3f | 0xc0) . chr($codepoint & 0x3f | 0x80);
	}
	if ($codepoint < 0x10000)
	{
		return chr($codepoint >> 12 & 0x0f | 0xe0) . chr($codepoint >> 6 & 0x3f | 0x80) . chr($codepoint & 0x3f | 0x80);
	}
	if ($codepoint < 0x110000)
	{
		return chr($codepoint >> 18 & 0x07 | 0xf0) . chr($codepoint >> 12 & 0x3f | 0x80) . chr($codepoint >> 6 & 0x3f | 0x80) . chr($codepoint & 0x3f | 0x80);
	}

	echo "Asked for code outside of range ($codepoint)\n";
	die(-1);
}

/**
 * Take a series of space-separated hexadecimal numbers representing
 * Unicode code points and return a UTF-8 string composed of those
 * characters. Used by UTF-8 data generation and testing routines.
 *
 * @param   $sequence String
 * @return  String
 * @private
 */
function hexSequenceToUtf8($sequence)
{
	$utf = '';
	foreach (explode(' ', $sequence) as $hex)
	{
		$n = hexdec($hex);
		$utf .= codepointToUtf8($n);
	}
	return $utf;
}

/**
 * Take a UTF-8 string and return a space-separated series of hex
 * numbers representing Unicode code points. For debugging.
 *
 * @param   $str   String: UTF-8 string.
 * @return  string
 * @private
 */
function utf8ToHexSequence($str)
{
	return rtrim(preg_replace('/(.)/uSe', 'sprintf("%04x ", utf8ToCodepoint("$1"))', $str));
}

/**
 * Determine the Unicode codepoint of a single-character UTF-8 sequence.
 * Does not check for invalid input data.
 *
 * @param  $char   String
 * @return Integer
 * @public
 */
function utf8ToCodepoint($char)
{
	# Find the length
	$z = ord($char{0});
	if ($z & 0x80)
	{
		$length = 0;
		while ($z & 0x80)
		{
			$length++;
			$z <<= 1;
		}
	}
	else
	{
		$length = 1;
	}

	if ($length != strlen($char))
	{
		return false;
	}
	if ($length == 1)
	{
		return ord($char);
	}

	# Mask off the length-determining bits and shift back to the original location
	$z &= 0xff;
	$z >>= $length;

	# Add in the free bits from subsequent bytes
	for ($i=1; $i<$length; $i++)
	{
		$z <<= 6;
		$z |= ord($char{$i}) & 0x3f;
	}

	return $z;
}

/**
 * Escape a string for inclusion in a PHP single-quoted string literal.
 *
 * @param  $string String: string to be escaped.
 * @return String: escaped string.
 * @public
 */
function escapeSingleString($string)
{
	return strtr($string,
		array(
			'\\' => '\\\\',
			'\'' => '\\\''
		));
}
